/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

Components.utils.import("resource://gre/modules/Services.jsm");
Components.utils.import("resource://gre/modules/PluralForm.jsm");

const NS_ALERT_HORIZONTAL = 1;
const NS_ALERT_LEFT = 2;
const NS_ALERT_TOP = 4;

var gOpenTime = 6000; // total time the alert should stay up once we are done animating.
var gOrigin = 0; // Default value: alert from bottom right, sliding in vertically.

// var gAlertTextClickable = false;

var bundle = Services.strings.createBundle("chrome://calalarmslider/locale/overlay.properties");
var gAlarmSliderTitleLabel = bundle.GetStringFromName( "alarmSliderTitle.label" );
var gAlarmSliderTextLabel = bundle.GetStringFromName( "alarmSliderText.label" );

function prefillAlertInfo() {
    let calAlarmWindow = Services.wm.getMostRecentWindow("Calendar:AlarmWindow");
    let alarmRichlist = calAlarmWindow.document.getElementById("alarm-richlist");
    let reminders = alarmRichlist.childNodes.length;

    let title = document.getElementById("alertTitleLabel");
    let titleString = PluralForm.get(reminders, gAlarmSliderTitleLabel);
    let finishedTitleString = titleString.replace("#1", reminders);
    title.setAttribute("value", finishedTitleString + "  ");

    document.getElementById("alertImage").src = "chrome://calendar/skin/cal-icon32.png";

    let alertTextLabel = document.getElementById("alertTextLabel");
    let textString = PluralForm.get(reminders, gAlarmSliderTextLabel);
    let finishedTextString = textString.replace("#1", reminders);
    alertTextLabel.setAttribute("value", finishedTextString + "  ");
}

function onAlertLoad() {
    // Read out our initial settings from prefs.
    try {
        gOpenTime = Services.prefs.getIntPref("calAlarmSlider.totalOpenTime");
    }
    catch (ex) {
    }

    let alertTextBox = document.getElementById("alertTextBox");
    let alertImageBox = document.getElementById("alertImageBox");
    alertImageBox.style.minHeight = alertTextBox.scrollHeight + "px";

    sizeToContent();

    // Determine position
    let x = gOrigin & NS_ALERT_LEFT ? screen.availLeft :
            screen.availLeft + screen.availWidth - window.outerWidth;
    let y = gOrigin & NS_ALERT_TOP ? screen.availTop :
            screen.availTop + screen.availHeight - window.outerHeight;

    // Offset the alert by 10 pixels from the edge of the screen
    y += gOrigin & NS_ALERT_TOP ? 10 : -10;
    x += gOrigin & NS_ALERT_LEFT ? 10 : -10;

    window.moveTo(x, y);

    let showPermanentSlider = Services.prefs.getBoolPref("calAlarmSlider.showPermanentSlider");
    if (showPermanentSlider == true) {
        return;
    } else {
        setTimeout(closeAlert, gOpenTime);
    }
}

function closeAlert() {
    window.close();
}

function onSliderClick() {
    let calAlarmWindow = Services.wm.getMostRecentWindow("Calendar:AlarmWindow");
    let timeoutSet = Services.prefs.getBoolPref("calAlarmSlider.timeoutSet");
    if (timeoutSet == true) {
        Services.prefs.setBoolPref("calAlarmSlider.timeoutSet", false);
        if (calAlarmWindow) {
            calAlarmWindow.clearSliderTimeout();
        }
    }
    if (calAlarmWindow) {
        calAlarmWindow.focus();
    }
    window.close();
}

function updateSliderTexts() {
    let calAlarmWindow = Services.wm.getMostRecentWindow("Calendar:AlarmWindow");
    let sliderWindow = Services.wm.getMostRecentWindow("Calendar:AlarmSliderWindow");
    if (calAlarmWindow && sliderWindow) {
        let alarmRichlist = calAlarmWindow.document.getElementById("alarm-richlist");
        let reminders = alarmRichlist.childNodes.length;

        let title = sliderWindow.document.getElementById("alertTitleLabel");
        let titleString = PluralForm.get(reminders, gAlarmSliderTitleLabel);
        let finishedTitleString = titleString.replace("#1", reminders);
        title.setAttribute("value", finishedTitleString);

        let alertTextLabel = sliderWindow.document.getElementById("alertTextLabel");
        let textString = PluralForm.get(reminders, gAlarmSliderTextLabel);
        let finishedTextString = textString.replace("#1", reminders);
        alertTextLabel.setAttribute("value", finishedTextString);
    }
}
